import{j as r}from"./vendor-tanstack-DE4ALVGD.js";import{s as m}from"./index-CNL5pSma.js";import{R as s}from"./route-error-state-57m9g0tL.js";import"./vendor-react-HBv6Kpyp.js";import"./vendor-radix-K8EF6rBE.js";import"./vendor-recharts-B3wzJa9e.js";import"./vendor-forms-BvpM0AtX.js";import"./vendor-date-Bck8LDfw.js";function f({error:o,reset:e}){const t=m(o,"Failed to load deployment");return r.jsxs("div",{className:"flex flex-col gap-4",children:[r.jsx("div",{children:r.jsx("h1",{className:"text-2xl font-semibold",children:"Deployment"})}),r.jsx(s,{error:t,onRetry:e})]})}export{f as errorComponent};
//# sourceMappingURL=deployment._id-BLt2P5FF.js.map
