import{j as a}from"./vendor-tanstack-DE4ALVGD.js";import{L as n,aZ as o,f}from"./index-CNL5pSma.js";function p({value:e,className:t,hideLineNumbers:s=!0,copy:r=!0,...i}){return a.jsx(n,{value:e,disabled:!0,hideLineNumbers:s,copy:r,className:o("bg-muted/50",t),...i})}function u(e){const t=[],s=e.split(".");for(let r=1;r<s.length;r++){const i=s.slice(0,r).join(".");t.push(`${i}.*`)}return[...t,e]}function m(e){let t=e;return t.startsWith("prefect.")?t=t.slice(8):t.startsWith("prefect-cloud.")&&(t=t.slice(14)),t.split(/[._-]/).map(s=>f(s.toLowerCase())).join(" ")}export{p as J,m as f,u as g};
//# sourceMappingURL=utilities-CAE5cWs6.js.map
