import{s as m,j as o}from"./vendor-tanstack-DE4ALVGD.js";import{ct as r,dO as p}from"./index-CNL5pSma.js";import{D as i}from"./deployment-action-header-Dgy5Zuy9.js";import{D as s}from"./deployment-form-y7MPD9_9.js";import"./vendor-react-HBv6Kpyp.js";import"./vendor-radix-K8EF6rBE.js";import"./vendor-recharts-B3wzJa9e.js";import"./vendor-forms-BvpM0AtX.js";import"./vendor-date-Bck8LDfw.js";import"./schema-form-input-string-format-datetime-B98i_B5d.js";import"./zod-2_bJZbih.js";import"./use-debounce-callback-_1tAtOwa.js";import"./timezone-select-zsZ2PBlt.js";import"./dropdown-menu-D34zumpn.js";import"./form-_6uPI_KA.js";import"./tags-input-CZLIJjbu.js";const n=({id:t})=>{const{data:e}=m(r(t));return o.jsxs("div",{className:"flex flex-col gap-4",children:[o.jsx(i,{deployment:e,action:"Duplicate"}),o.jsx(s,{deployment:e,mode:"duplicate"})]})};function v(){const{id:t}=p.useParams();return o.jsx(n,{id:t})}export{v as component};
//# sourceMappingURL=deployment_._id.duplicate-D2d21NEd.js.map
