import{j as o}from"./vendor-tanstack-DE4ALVGD.js";import{s as m}from"./index-CNL5pSma.js";import{D as s}from"./header-BddV4oks.js";import{R as p}from"./route-error-state-57m9g0tL.js";import"./vendor-react-HBv6Kpyp.js";import"./vendor-radix-K8EF6rBE.js";import"./vendor-recharts-B3wzJa9e.js";import"./vendor-forms-BvpM0AtX.js";import"./vendor-date-Bck8LDfw.js";function j({error:e,reset:t}){const r=m(e,"Failed to load deployments");if(r.type!=="server-error"&&r.type!=="client-error")throw e;return o.jsxs("div",{className:"flex flex-col gap-4",children:[o.jsx(s,{}),o.jsx(p,{error:r,onRetry:t})]})}export{j as errorComponent};
//# sourceMappingURL=index-DnxPI5rX.js.map
