import{r as o}from"./vendor-tanstack-DE4ALVGD.js";const p=()=>{const[n,e]=o.useState({isOpen:!1,title:"",description:"",onConfirm:()=>{},onClose:()=>e(t=>({...t,isOpen:!1}))}),s=o.useCallback(({title:t="Confirm Deletion",description:i="Are you sure you want to delete this item? This action cannot be undone.",confirmText:a,isLoading:l=!1,loadingText:r="Deleting...",onConfirm:u})=>{e({isOpen:!0,title:t,description:i,confirmText:a,isLoading:l,loadingText:r,onConfirm:u,onClose:()=>e(c=>({...c,isOpen:!1}))})},[]);return[n,s]};export{p as u};
//# sourceMappingURL=use-delete-confirmation-dialog-mtiBAiyE.js.map
