const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/vendor-markdown-BeddnEP6.js","assets/vendor-tanstack-DE4ALVGD.js","assets/vendor-react-HBv6Kpyp.js"])))=>i.map(i=>d[i]);
import{ce as r,b8 as _}from"./index-CNL5pSma.js";import{r as e,j as s}from"./vendor-tanstack-DE4ALVGD.js";function c({children:a,...i}){const[o,u]=e.useState(null),[n,l]=e.useState(null);return e.useEffect(()=>{Promise.all([r(()=>import("./vendor-markdown-BeddnEP6.js").then(t=>t.i),__vite__mapDeps([0,1,2])),r(()=>import("./vendor-markdown-BeddnEP6.js").then(t=>t.a),__vite__mapDeps([0,1,2]))]).then(([t,m])=>{u(()=>t.default),l(()=>m.default)})},[]),!o||!n?s.jsx(_,{className:"min-h-[100px]"}):s.jsx(o,{remarkPlugins:[n],...i,children:a})}export{c as L};
//# sourceMappingURL=lazy-markdown-Ds39cUgX.js.map
