import{j as t}from"./vendor-tanstack-DE4ALVGD.js";import{f as o,H as r,cD as d,bM as n,d5 as a}from"./index-CNL5pSma.js";const i={READY:t.jsx(a,{size:12,fill:"green"}),NOT_READY:t.jsx(a,{size:12,fill:"red"}),PAUSED:t.jsx(n,{size:12})},g=d("gap-2 px-2 text-foreground/80 font-mono font-light border border-foreground/10 shadow-none text-nowrap",{variants:{status:{READY:"bg-state-completed-100 hover:bg-state-completed-100 dark:bg-state-completed-900 dark:hover:bg-state-completed-900",NOT_READY:"bg-state-failed-100 hover:bg-state-failed-100 dark:bg-state-failed-900 dark:hover:bg-state-failed-900",PAUSED:"bg-state-pending-200 hover:bg-state-pending-200 dark:bg-state-pending-800 dark:hover:bg-state-pending-800"}}}),l=({status:e})=>i[e],b=({status:e})=>{const s=e.split("_").map(o).join(" ");return t.jsxs(r,{className:g({status:e}),children:[t.jsx(l,{status:e}),s]})};export{b as S,l as a};
//# sourceMappingURL=index-D4OtcoMT.js.map
