import{s as n,j as t}from"./vendor-tanstack-DE4ALVGD.js";import{d9 as m,B as l,g as c,h as a,bv as u,bE as d,bG as x,dx as j}from"./index-CNL5pSma.js";import{D as p}from"./delete-confirmation-dialog-Blb6Fypx.js";import{u as f,A as b,a as g,b as h,c as A,d as D}from"./use-delete-automation-confirmation-dialog-KDrkiks7.js";import"./vendor-react-HBv6Kpyp.js";import"./vendor-radix-K8EF6rBE.js";import"./vendor-recharts-B3wzJa9e.js";import"./vendor-forms-BvpM0AtX.js";import"./vendor-date-Bck8LDfw.js";import"./work-queue-icon-text-BEuAdpzO.js";import"./index-D4OtcoMT.js";import"./dropdown-menu-D34zumpn.js";import"./use-delete-confirmation-dialog-mtiBAiyE.js";const N=({id:s})=>{const[o,i]=f(),{data:e}=n(m(s)),r=()=>i(e,{shouldNavigate:!0});return t.jsxs(t.Fragment,{children:[t.jsxs("div",{className:"flex flex-col gap-6",children:[t.jsxs("div",{className:"flex items-center justify-between",children:[t.jsx(v,{automation:e}),t.jsxs("div",{className:"flex items-center gap-2",children:[t.jsx(b,{automation:e}),t.jsx(g,{id:e.id,onDelete:r})]})]}),t.jsxs("div",{className:"flex flex-col gap-4",children:[t.jsx(h,{automation:e}),t.jsx(A,{automation:e}),t.jsx(D,{automation:e})]})]}),t.jsx(p,{...o})]})},v=({automation:s})=>t.jsx(l,{children:t.jsxs(c,{children:[t.jsx(a,{children:t.jsx(u,{to:"/automations",className:"text-xl font-semibold",children:"Automations"})}),t.jsx(d,{}),t.jsx(a,{className:"text-xl font-semibold",children:t.jsx(x,{children:s.name})})]})});function F(){const{id:s}=j.useParams();return t.jsx(N,{id:s})}export{F as component};
//# sourceMappingURL=automation._id-CQZICIp5.js.map
